@@ -1,9 +1,11 @@
 import ast
 import sys
+from pathlib import Path
 
 from inline_snapshot import external
 from inline_snapshot import outsource
 from inline_snapshot import snapshot
+from inline_snapshot._external._external_location import ExternalLocation
 from inline_snapshot._external._find_external import ensure_import
 from inline_snapshot._external._find_external import used_externals_in
 from inline_snapshot._global_state import snapshot_env
@@ -366,13 +368,27 @@ def test_errors():
 
 def test_uses_external():
     assert used_externals_in(
-        ast.parse("[external('hash:111*.txt')]"), check_import=False
-    ) == snapshot({"hash:111*.txt"})
-    assert not used_externals_in(ast.parse("[external()]"), check_import=False)
-    assert not used_externals_in(ast.parse("[external]"), check_import=False)
+        Path("a.py"), ast.parse("[external('hash:111*.txt')]"), check_import=False
+    ) == snapshot(
+        [
+            ExternalLocation(
+                storage="hash",
+                stem="111*",
+                suffix=".txt",
+                filename=Path("a.py"),
+                linenumber=1,
+            )
+        ]
+    )
+    assert not used_externals_in(
+        Path("a.py"), ast.parse("[external()]"), check_import=False
+    )
+    assert not used_externals_in(
+        Path("a.py"), ast.parse("[external]"), check_import=False
+    )
     assert used_externals_in(
-        ast.parse("[external('hash:111*.txt')]"), check_import=True
-    ) == snapshot(set())
+        Path("a.py"), ast.parse("[external('hash:111*.txt')]"), check_import=True
+    ) == snapshot([])
 
 
 def test_no_imports(project):
@@ -408,12 +424,11 @@ test_something()
 
 def test_ensure_imports(tmp_path):
     file = tmp_path / "file.py"
-    file.write_text(
-        """\
+    file.write_bytes(
+        b"""\
 from os import environ
 from os import getcwd
-""",
-        "utf-8",
+"""
     )
 
     with apply_changes() as recorder:
@@ -431,11 +446,10 @@ from os import chdir
 
 def test_ensure_imports_with_comment(tmp_path):
     file = tmp_path / "file.py"
-    file.write_text(
-        """\
+    file.write_bytes(
+        b"""\
 from os import environ # comment
-""",
-        "utf-8",
+"""
     )
 
     with apply_changes() as recorder:
@@ -742,59 +756,6 @@ E           inline_snapshot._exceptions.UsageError: can not load external object
     )
 
 
-def test_tests_dir():
-    Example(
-        {
-            "pyproject.toml": "# empty",
-            "example1.py": """\
-from inline_snapshot import external
-
-def test_a():
-    assert "hi" == external("hash:")
-""",
-            "tests/example2.py": """\
-from inline_snapshot import external
-
-def test_a():
-    assert "ho" == external("hash:")
-""",
-        }
-    ).run_pytest(
-        ["--inline-snapshot=create", "example1.py", "tests/example2.py"],
-        changed_files=snapshot(
-            {
-                ".inline-snapshot/external/8f434346648f6b96df89dda901c5176b10a6d83961dd3c1ac88b59b2dc327aa4.txt": "hi",
-                ".inline-snapshot/external/a821c62e8104f8519d639b4c0948aece641b143f6601fa145993bb2e2c7299d4.txt": "ho",
-                "example1.py": """\
-from inline_snapshot import external
-
-def test_a():
-    assert "hi" == external("hash:8f434346648f*.txt")
-""",
-                "tests/example2.py": """\
-from inline_snapshot import external
-
-def test_a():
-    assert "ho" == external("hash:a821c62e8104*.txt")
-""",
-            }
-        ),
-        returncode=snapshot(1),
-    ).run_pytest(
-        ["--inline-snapshot=trim", "example1.py"],
-        changed_files=snapshot({}),
-        returncode=snapshot(0),
-    ).run_pytest(
-        ["--inline-snapshot=trim", "tests/example2.py"],
-        changed_files=snapshot(
-            {
-                ".inline-snapshot/external/8f434346648f6b96df89dda901c5176b10a6d83961dd3c1ac88b59b2dc327aa4.txt": None
-            }
-        ),
-        returncode=snapshot(0),
-    )
-
-
 def test_report():
     # see https://github.com/15r10nk/inline-snapshot/issues/298
 
@@ -882,3 +843,25 @@ Use --inline-snapshot=fix to apply them, or use the interactive mode with
         ),
         returncode=snapshot(1),
     )
+
+
+def test_uses_external_outside_testdir():
+    Example(
+        {
+            "test_a.py": """\
+from inline_snapshot import external
+
+def test_a():
+    assert "a" == external()
+"""
+        }
+    ).run_inline(
+        ["--inline-snapshot=create"],
+        changed_files=snapshot({}),
+        raises=snapshot(
+            """\
+UsageError:
+external() can only be used in files which are inside tests/ or any other folder defined by your tool.inline-snapshot.test-dir in pyproject.toml\
+"""
+        ),
+    )
