@@ -16,11 +16,15 @@ from typing import Optional
 from typing import TypeVar
 
 import pytest
+from executing import is_pytest_compatible
 
 from inline_snapshot import snapshot
+from inline_snapshot._external._external_file import external_file
 from inline_snapshot._flags import Flags
+from inline_snapshot._global_state import snapshot_env
 from inline_snapshot.extra import raises
 from inline_snapshot.testing import Example
+from inline_snapshot.version import is_insider
 
 
 @dataclass
@@ -31,7 +35,7 @@ class Block:
     line: int
 
 
-def map_code_blocks(file: Path, func, fix: bool = False):
+def map_code_blocks(file: Path, func):
 
     block_start = re.compile("( *)``` *python(.*)")
     block_end = re.compile("```.*")
@@ -128,11 +132,7 @@ def map_code_blocks(file: Path, func, fix: bool = False):
 
     new_code = "\n".join(new_lines) + "\n"
 
-    if fix:
-        file.write_text(new_code)
-    else:
-        assert current_code.splitlines() == new_code.splitlines()
-        assert current_code == new_code
+    assert external_file(file, format=".txt") == new_code
 
 
 def test_map_code_blocks(tmp_path):
@@ -147,7 +147,7 @@ def test_map_code_blocks(tmp_path):
         new_markdown_code=None,
     ):
 
-        file.write_text(markdown_code)
+        file.write_bytes(markdown_code.encode("utf-8"))
 
         recorded_blocks = []
 
@@ -158,9 +158,20 @@ def test_map_code_blocks(tmp_path):
                 recorded_blocks.append(block)
                 return block
 
-            map_code_blocks(file, test_block, True)
+            with snapshot_env() as state:
+                state.update_flags.fix = True
+                state.active = True
+
+                map_code_blocks(file, test_block)
+
+                for snapshot in state.snapshots.values():
+                    for change in snapshot._changes():
+                        change.apply_external_changes()
+
             assert recorded_blocks == blocks
-            map_code_blocks(file, test_block, False)
+
+            with snapshot_env():
+                map_code_blocks(file, test_block)
 
         recorded_markdown_code = file.read_text()
         if recorded_markdown_code != markdown_code:
@@ -277,7 +288,6 @@ class Store(Generic[T]):
 def file_test(
     file: Path,
     subtests,
-    fix_files: bool = False,
     width: int = 80,
     use_hl_lines: bool = True,
 ):
@@ -293,6 +303,9 @@ def file_test(
 
     std_files = {
         "pyproject.toml": f"""
+[tool.inline-snapshot]
+format-command="black --stdin-filename {{filename}} -"
+
 [tool.black]
 line-length={width}
 """,
@@ -315,6 +328,18 @@ def _(value:FakeDate):
 def set_time(freezer):
         freezer.move_to(datetime.datetime(2024, 3, 14, 0, 0, 0, 0))
         yield
+
+import uuid
+import random
+
+rd = random.Random(0)
+
+def f():
+    return uuid.UUID(int=rd.getrandbits(128), version=4)
+
+uuid.uuid4=f
+
+
 """,
     }
 
@@ -328,21 +353,24 @@ def set_time(freezer):
             extra_files[block.code_header.split()[1]].append(block.code)
             return block
 
+        if block.code_header.startswith("inline-snapshot-lib-set:"):
+            extra_files[block.code_header.split()[1]] = [block.code]
+            return block
+
         if block.code_header.startswith("todo-inline-snapshot:"):
             return block
 
         nonlocal last_code
         with subtests.test(line=block.line):
+            print(f"test block line {block.line}")
 
             code = block.code
 
             options = set(block.code_header.split())
 
-            # if "requires_assert" in options and not is_pytest_compatible():
-            #    return block
-
-            if "requires_assert" in options:
-                # wen can not test the docs in the no insider version
+            if "requires_assert" in options and (
+                not is_pytest_compatible() or not is_insider
+            ):
                 return block
 
             flags = options & Flags.all().to_set()
@@ -355,9 +383,9 @@ def set_time(freezer):
 
             if flags and "first_block" not in options:
                 assert last_code is not None
-                test_files = {"test_example.py": last_code}
+                test_files = {"tests/test_example.py": last_code}
             else:
-                test_files = {"test_example.py": code}
+                test_files = {"tests/test_example.py": code}
 
             example = Example({**std_files, **test_files})
             if extra_files:
@@ -368,6 +396,7 @@ def set_time(freezer):
                 for files in itertools.product(*all_files):
                     example = example.with_files(dict(files))
 
+                    print("run with")
                     example = example.run_pytest(
                         args, error=errors, outcomes=outcomes, returncode=returncode
                     )
@@ -381,7 +410,7 @@ def set_time(freezer):
 
             new_code = code
             if flags:
-                new_code = example.files["test_example.py"]
+                new_code = example.read_file("tests/test_example.py")
             new_code.replace("\n\n", "\n")
 
             if "show_error" in options:
@@ -408,6 +437,7 @@ def set_time(freezer):
 
                 linenum = 1
                 hl_lines = ""
+
                 if last_code is not None and "first_block" not in options:
                     changed_lines = []
                     alignment = align(last_code.split("\n"), new_code.split("\n"))
@@ -432,7 +462,7 @@ def set_time(freezer):
             last_code = code
         return block
 
-    map_code_blocks(file, test_block, fix_files)
+    map_code_blocks(file, test_block)
 
 
 if __name__ == "__main__":  # pragma: no cover
@@ -448,4 +478,4 @@ if __name__ == "__main__":  # pragma: no cover
 
     nosubtests = SimpleNamespace(test=test)
 
-    file_test(file, nosubtests, fix_files=True, width=60, use_hl_lines=False)
+    file_test(file, nosubtests, width=60, use_hl_lines=True)
